<template>
	<div>
		<div class="row cs-blocks">
			<div
				v-for="item in sortedItems"
				:key="item.id"
				class="col col-12 col-md-6 col-xl-3 mb-1"
			>
				<a
					:class="item.medium"
					:href="!item.button_action ? item.button_url : null"
					:target="!item.button_action ? item.target : null"
					class="h-100 option d-flex"
					rel="noopener"
					@click="
						item.button_action ? handleItemClick(item.button_action) : null
					"
				>
					<div class="contact-method px-lg-1 pt-lg-1">
						<svg class="ok-icon">
							<use :xlink:href="`${iconUrl}#${item.id}`"></use>
						</svg>
						<span>
							{{ item.text_short }}
						</span>
					</div>
					<span class="d-none d-lg-block cta">
						{{ item.button_title }}
					</span>
				</a>
			</div>
		</div>
		<div class="row">
			<div class="col col-12">
				<small v-html="footerText" class="d-md-none d-lg-inline-flex"> </small>
			</div>
		</div>
	</div>
</template>

<script>
	module.exports = {
		name: "CustomerServiceBlock",
		data() {
			return {};
		},
		props: {
			footerText: String,
			iconUrl: String,
			items: Array,
			translations: Object,
		},
		methods: {
			handleItemClick(action) {
				if (action === "open-chat") {
					if (window.Grasp) {
						window.Grasp.fn.openMessenger();
					} else {
						this.showError(translations.liveChatUnavailable);
					}
				} else {
					console.error("Unknown action", action);
				}
			},
			showError(text) {
				let config = {
					autoHideDuration: 3,
					background: "#2b2b2b",
					button: translations.dismiss,
					text: text,
				};
				this.$snack["danger"](config);
			},
		},
		computed: {
			sortedItems() {
				return this.items
					.slice()
					.sort((a, b) => a.position - b.position)
					.map(item => ({
						medium: item.name.toLowerCase().replaceAll(" ", "-"),
						...item,
					}));
			},
		},
	};
</script>

<style>
	.customerservice {
		margin: 67.5px 0;
	}
	.cs-blocks .col {
		padding-left: 7.5px;
		padding-right: 7.5px;
	}
	.customerservice .cs-blocks .option {
		border: 1px solid #2b2b2b;
		color: #2b2b2b;
		padding: 7px 15px;
		margin-bottom: 15px;
	}
	.customerservice .cs-blocks .whatsapp {
		background: #075e54;
		color: #fff;
		border: none;
	}
	.customerservice .cs-blocks .facebook-messenger {
		background: #0084ff;
		color: #fff;
		border: none;
	}
	@media (min-width: 992px) {
		.customerservice .cs-blocks .option {
			border: 1px solid #e6e6e6;
			background: #fff;
			color: #2b2b2b;
			padding: 0;
			margin: 0;
			justify-content: space-between;
		}
		.customerservice .cs-blocks .option .cta {
			background: #9b9258;
			color: #fff;
			margin: 15px;
			padding: 7px 15px;
		}
		.customerservice .cs-blocks .whatsapp .cta {
			background: #075e54;
		}
		.customerservice .cs-blocks .facebook-messenger .cta {
			background: #0084ff;
		}
	}
	@media (min-width: 992px) {
		.customerservice .cs-blocks a {
			background: #f4f4f4;
			margin: 15px;
			padding: 0;
			display: flex;
			flex-direction: column;
			justify-content: space-between;
		}
		.customerservice .cs-blocks a a {
			display: block;
			margin: 15px;
			padding: 7px 15px;
			background: #9b9258;
			color: #fff !important;
		}
		.customerservice .cs-blocks a a.whatsapp {
			background: #075e54;
		}
		.customerservice .cs-blocks a a.facebook-messenger {
			background: #0084ff;
		}
		.customerservice .cs-blocks .time-indication {
			background: #2b2b2b;
			color: #fff;
			display: block;
			width: 100%;
			padding: 10px;
			font-size: 0.7em;
		}
	}
	.customerservice .cs-blocks .contact-method {
		display: flex;
		padding: 0;
		align-items: center;
		font-size: 13px;
		line-height: 15px;
	}
	.customerservice .cs-blocks .contact-method svg {
		min-width: 30px;
		width: 30px;
		height: 30px;
		margin-right: 15px;
	}
	.customerservice .cs-blocks .contact-method span {
		text-align: left;
		line-height: 20px;
	}
	@media (min-width: 576px) {
		.customerservice .cs-blocks .contact-method {
			font-size: 15px;
			line-height: 17px;
		}
	}
	.customerservice small {
		display: block;
		text-align: left;
	}
	.customerservice small span {
		display: inline-block;
		height: 40px;
		margin-right: 7px;
	}
</style>
